@@ -1,7 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-import cluttergtk # must be the first to be imported
-import clutter
 import gobject
 import gtk
 import champlain
@@ -18,14 +16,30 @@ class LauncherGTK:
 
         vbox = gtk.VBox(False, 12)
 
-        self.view = champlain.View()
-        self.view.set_property("scroll-mode", champlain.SCROLL_MODE_KINETIC)
+        embed = champlaingtk.ChamplainEmbed()
+        embed.set_size_request(640, 480)
+
+        self.view = embed.get_view()
 
         self.layer = create_marker_layer(self.view)
         self.view.add_layer(self.layer)
+        self.layer.hide_all_markers()
 
-        embed = cluttergtk.Embed()
-        embed.set_size_request(640, 480)
+        self.polygon = polygon = champlain.Polygon()
+        # Cheap approx of Highway 10
+        polygon.append_point(45.4095, -73.3197)
+        polygon.append_point(45.4104, -73.2846)
+        polygon.append_point(45.4178, -73.2239)
+        polygon.append_point(45.4176, -73.2181)
+        polygon.append_point(45.4151, -73.2126)
+        polygon.append_point(45.4016, -73.1926)
+        polygon.append_point(45.3994, -73.1877)
+        polygon.append_point(45.4000, -73.1815)
+        polygon.append_point(45.4151, -73.1218)
+        polygon.set_stroke_width(5.0);
+        polygon.set_property("mark-points", True)
+        self.view.add_polygon(polygon)
+        polygon.hide()
 
         bbox = gtk.HBox(False, 6)
         button = gtk.Button(stock=gtk.STOCK_ZOOM_IN)
@@ -37,6 +51,7 @@ class LauncherGTK:
         bbox.add(button)
 
         button = gtk.ToggleButton(label="Markers")
+        button.set_active(False)
         button.connect("toggled", self.toggle_layer)
         bbox.add(button)
 
@@ -63,12 +78,6 @@ class LauncherGTK:
         vbox.add(embed)
 
         self.window.add(vbox)
-        # we need to realize the widget before we get the stage
-        embed.realize()
-
-        stage = embed.get_stage()
-        self.view.set_size(640, 480)
-        stage.add(self.view)
 
         self.window.show_all()
         self.view.center_on(45.466, -73.75)
@@ -81,8 +90,10 @@ class LauncherGTK:
 
     def toggle_layer(self, widget):
         if widget.get_active():
+            self.polygon.show()    
             self.layer.animate_in_all_markers()
         else:
+            self.polygon.hide()    
             self.layer.animate_out_all_markers()
 
     def zoom_changed(self, widget):
