@@ -210,8 +210,12 @@ champlain_cache_init (ChamplainCache *self)
   priv->popularity_queue = NULL;
   priv->popularity_id = 0;
 
+#ifdef USE_MAEMO
+  filename = g_strdup_printf ("/home/user/MyDocs/.maps/champlain-cache.db");
+#else
   filename = g_build_filename (g_get_user_cache_dir (), "champlain",
       "cache.db", NULL);
+#endif
 
   champlain_cache_set_size_limit (self, 100000000);
 
@@ -237,16 +241,28 @@ champlain_cache_init (ChamplainCache *self)
       goto cleanup;
     }
 
+  sqlite3_exec (priv->data,
+      "PRAGMA synchronous=OFF;"
+      "PRAGMA count_changes=OFF;",
+      NULL, NULL, &error_msg);
+  if (error_msg != NULL)
+    {
+      DEBUG ("Set PRAGMA: %s", error_msg);
+      sqlite3_free (error_msg);
+      goto cleanup;
+    }
+
   sqlite3_exec (priv->data,
       "CREATE TABLE IF NOT EXISTS tiles ("
-      "filename TEXT PRIMARY KEY, etag TEXT, "
+      "filename TEXT PRIMARY KEY, "
+      "etag TEXT, "
       "popularity INT DEFAULT 1, "
       "size INT DEFAULT 0)",
       NULL, NULL, &error_msg);
   if (error_msg != NULL)
     {
       DEBUG ("Creating table 'tiles' failed: %s", error_msg);
-          sqlite3_free (error_msg);
+      sqlite3_free (error_msg);
       goto cleanup;
     }
 
@@ -362,13 +378,14 @@ champlain_cache_fill_tile (ChamplainCache *self,
   ChamplainCachePrivate *priv = GET_PRIVATE (self);
 
   filename = champlain_tile_get_filename (tile);
+  DEBUG ("fill of %s", filename);
 
   if (!g_file_test (filename, G_FILE_TEST_EXISTS))
     goto cleanup;
 
   file = g_file_new_for_path (filename);
   info = g_file_query_info (file,
-      G_FILE_ATTRIBUTE_TIME_MODIFIED "," G_FILE_ATTRIBUTE_ETAG_VALUE,
+      G_FILE_ATTRIBUTE_TIME_MODIFIED,
       G_FILE_QUERY_INFO_NONE, NULL, NULL);
   g_file_info_get_modification_time (info, &modified_time);
   champlain_tile_set_modified_time (tile, &modified_time);
@@ -404,7 +421,9 @@ champlain_cache_fill_tile (ChamplainCache *self,
     }
 
   /* Load the cached version */
-  actor = clutter_texture_new_from_file (filename, &error);
+  actor = clutter_texture_new ();
+  clutter_texture_set_load_async (CLUTTER_TEXTURE (actor), TRUE);
+  clutter_texture_set_from_file (CLUTTER_TEXTURE (actor), filename, &error);
   if (error == NULL)
     {
         champlain_tile_set_content (tile, actor, FALSE);
@@ -460,6 +479,8 @@ champlain_cache_tile_is_expired (ChamplainCache *self,
   g_time_val_add (&now, (-24ul * 60ul * 60ul * 1000ul * 1000ul * 7ul)); // Cache expires 7 days
   validate_cache = modified_time->tv_sec < now.tv_sec;
 
+  DEBUG ("%p is %s expired", tile, (validate_cache ? "": "not"));
+
   return validate_cache;
 }
 
@@ -481,6 +502,8 @@ inc_popularity (gpointer data)
   last = g_slist_last (priv->popularity_queue);
   filename = last->data;
 
+  DEBUG ("popularity of %s", filename);
+
   sql_rc = sqlite3_bind_text (priv->stmt_update, 1, filename, -1, SQLITE_STATIC);
   if (sql_rc != SQLITE_OK)
     {
@@ -504,7 +527,7 @@ cleanup:
   g_free (filename);
 
   /* Ask to be called again until the list is emptied */
-  return TRUE;
+  return priv->popularity_queue != NULL;
 }
 
 static void
@@ -560,6 +583,8 @@ champlain_cache_update_tile (ChamplainCache *self,
 
   ChamplainCachePrivate *priv = GET_PRIVATE (self);
 
+  DEBUG ("Update of %p", tile);
+
   query = sqlite3_mprintf ("REPLACE INTO tiles (filename, etag, size) VALUES (%Q, %Q, %d)",
       champlain_tile_get_filename (tile),
       champlain_tile_get_etag (tile),
