@@ -46,7 +46,6 @@
 #include "champlain-zoom-level.h"
 
 #include <clutter/clutter.h>
-#include <clutter-cairo/clutter-cairo.h>
 #include <glib.h>
 #include <glib-object.h>
 #include <cairo.h>
@@ -56,6 +55,7 @@
 #define DEFAULT_FONT_NAME "Sans 11"
 
 static ClutterColor SELECTED_COLOR = {0x00, 0x33, 0xcc, 0xff};
+static ClutterColor SELECTED_TEXT_COLOR = {0xff, 0xff, 0xff, 0xff};
 
 static ClutterColor DEFAULT_COLOR = {0x33, 0x33, 0x33, 0xff};
 static ClutterColor DEFAULT_TEXT_COLOR = {0xee, 0xee, 0xee, 0xff};
@@ -113,16 +113,16 @@ G_DEFINE_TYPE (ChamplainMarker, champlain_marker, CHAMPLAIN_TYPE_BASE_MARKER);
 #define CHAMPLAIN_MARKER_GET_PRIVATE(obj)    (G_TYPE_INSTANCE_GET_PRIVATE((obj), CHAMPLAIN_TYPE_MARKER, ChamplainMarkerPrivate))
 
 static void draw_marker (ChamplainMarker *marker);
-static void queue_redraw (ChamplainMarker *marker);
 
 /**
  * champlain_marker_set_hightlight_color:
  * @color: a #ClutterColor
  *
+ *
  * Changes the highlight color, this is to ensure a better integration with
  * the desktop, this is automatically done by GtkChamplainEmbed.
  *
- * Since: 0.2
+ * Since: 0.4
  */
 void
 champlain_marker_set_highlight_color (ClutterColor *color)
@@ -133,6 +133,51 @@ champlain_marker_set_highlight_color (ClutterColor *color)
   SELECTED_COLOR.alpha = color->alpha;
 }
 
+/**
+ * champlain_marker_get_hightlight_color:
+ *
+ * Returns: the highlight color. Should not be freed.
+ *
+ * Since: 0.4.1
+ */
+const ClutterColor *
+champlain_marker_get_highlight_color ()
+{
+  return &SELECTED_COLOR;
+}
+
+/**
+ * champlain_marker_set_hightlight_text_color:
+ * @color: a #ClutterColor
+ *
+ *
+ * Changes the highlight text color, this is to ensure a better integration with
+ * the desktop, this is automatically done by GtkChamplainEmbed.
+ *
+ * Since: 0.4
+ */
+void
+champlain_marker_set_highlight_text_color (ClutterColor *color)
+{
+  SELECTED_TEXT_COLOR.red = color->red;
+  SELECTED_TEXT_COLOR.green = color->green;
+  SELECTED_TEXT_COLOR.blue = color->blue;
+  SELECTED_TEXT_COLOR.alpha = color->alpha;
+}
+
+/**
+ * champlain_marker_get_hightlight_text_color:
+ *
+ * Returns: the highlight text color. Should not be freed.
+ *
+ * Since: 0.4.1
+ */
+const ClutterColor *
+champlain_marker_get_highlight_text_color ()
+{
+  return &SELECTED_TEXT_COLOR;
+}
+
 static void
 champlain_marker_get_property (GObject *object,
                                guint prop_id,
@@ -237,23 +282,72 @@ champlain_marker_set_property (GObject *object,
     }
 }
 
+static void
+champlain_marker_dispose (GObject *object)
+{
+  ChamplainMarkerPrivate *priv = CHAMPLAIN_MARKER (object)->priv;
+
+  if (priv->background)
+    {
+      g_object_unref (priv->background);
+      priv->background = NULL;
+    }
+
+  if (priv->shadow)
+    {
+      g_object_unref (priv->shadow);
+      priv->shadow = NULL;
+    }
+
+  if (priv->text_actor)
+    {
+      g_object_unref (priv->text_actor);
+      priv->text_actor = NULL;
+    }
+
+  if (priv->image)
+    {
+      g_object_unref (priv->image);
+      priv->image = NULL;
+    }
+
+  if (priv->attributes)
+    {
+      pango_attr_list_unref (priv->attributes);
+      priv->attributes = NULL;
+    }
+
+  G_OBJECT_CLASS (champlain_marker_parent_class)->dispose (object);
+}
+
 static void
 champlain_marker_finalize (GObject *object)
 {
-  ChamplainMarker *marker = CHAMPLAIN_MARKER (object);
-  ChamplainMarkerPrivate *priv = marker->priv;
+  ChamplainMarkerPrivate *priv = CHAMPLAIN_MARKER (object)->priv;
 
-  if (priv->text != NULL)
-    g_free (priv->text);
-  priv->text = NULL;
+  if (priv->text)
+    {
+      g_free (priv->text);
+      priv->text = NULL;
+    }
 
-  if (priv->image != NULL)
-    g_object_unref (priv->image);
-  priv->image = NULL;
+  if (priv->font_name)
+    {
+      g_free (priv->font_name);
+      priv->font_name = NULL;
+    }
 
-  if (priv->background != NULL)
-    g_object_unref (priv->background);
-  priv->background = NULL;
+  if (priv->color)
+    {
+      clutter_color_free (priv->color);
+      priv->color = NULL;
+    }
+
+  if (priv->text_color)
+    {
+      clutter_color_free (priv->text_color);
+      priv->text_color = NULL;
+    }
 
   if (priv->redraw_id)
     {
@@ -271,6 +365,7 @@ champlain_marker_class_init (ChamplainMarkerClass *markerClass)
 
   GObjectClass *object_class = G_OBJECT_CLASS (markerClass);
   object_class->finalize = champlain_marker_finalize;
+  object_class->dispose = champlain_marker_dispose;
   object_class->get_property = champlain_marker_get_property;
   object_class->set_property = champlain_marker_set_property;
 
@@ -468,8 +563,8 @@ draw_shadow (ChamplainMarker *marker,
   else
     x = -58 * slope;
 
-  shadow = clutter_cairo_new (width + x, (height + point));
-  cr = clutter_cairo_create (CLUTTER_CAIRO (shadow));
+  shadow = clutter_cairo_texture_new (width + x, (height + point));
+  cr = clutter_cairo_texture_create (CLUTTER_CAIRO_TEXTURE (shadow));
 
   cairo_matrix_init (&matrix,
       1, 0,
@@ -512,8 +607,8 @@ draw_background (ChamplainMarker *marker,
   ClutterColor darker_color;
   cairo_t *cr;
 
-  bg = clutter_cairo_new (width, height + point);
-  cr = clutter_cairo_create (CLUTTER_CAIRO (bg));
+  bg = clutter_cairo_texture_new (width, height + point);
+  cr = clutter_cairo_texture_create (CLUTTER_CAIRO_TEXTURE (bg));
 
   /* If selected, add the selection color to the marker's color */
   if (base_priv->highlighted)
@@ -558,6 +653,7 @@ static void
 draw_marker (ChamplainMarker *marker)
 {
   ChamplainMarkerPrivate *priv = marker->priv;
+  ChamplainBaseMarkerPrivate *base_priv = CHAMPLAIN_BASE_MARKER (marker)->priv;
   guint height = 0, point = 0;
   guint total_width = 0, total_height = 0;
 
@@ -572,22 +668,22 @@ draw_marker (ChamplainMarker *marker)
 
   if (priv->text != NULL && strlen (priv->text) > 0)
     {
-      ClutterLabel *label;
+      ClutterText *label;
       if (priv->text_actor == NULL)
-      {
-        priv->text_actor = clutter_label_new_with_text (priv->font_name, priv->text);
-        g_object_ref (priv->text_actor);
-      }
+        {
+          priv->text_actor = clutter_text_new_with_text (priv->font_name, priv->text);
+          g_object_ref (priv->text_actor);
+        }
 
-      label = CLUTTER_LABEL (priv->text_actor);
-      clutter_label_set_use_markup (label, priv->use_markup);
-      clutter_label_set_font_name (label, priv->font_name);
-      clutter_label_set_text (label, priv->text);
-      clutter_label_set_alignment (label, priv->alignment);
-      clutter_label_set_line_wrap (label, priv->wrap);
-      clutter_label_set_line_wrap_mode (label, priv->wrap_mode);
-      clutter_label_set_ellipsize (label, priv->ellipsize);
-      clutter_label_set_attributes (label, priv->attributes);
+      label = CLUTTER_TEXT (priv->text_actor);
+      clutter_text_set_font_name (label, priv->font_name);
+      clutter_text_set_text (label, priv->text);
+      clutter_text_set_line_alignment (label, priv->alignment);
+      clutter_text_set_line_wrap (label, priv->wrap);
+      clutter_text_set_line_wrap_mode (label, priv->wrap_mode);
+      clutter_text_set_ellipsize (label, priv->ellipsize);
+      clutter_text_set_attributes (label, priv->attributes);
+      clutter_text_set_use_markup (label, priv->use_markup);
 
       height = clutter_actor_get_height (priv->text_actor);
       if (priv->image != NULL)
@@ -605,7 +701,8 @@ draw_marker (ChamplainMarker *marker)
       if (height > total_height)
         total_height = height;
 
-      clutter_label_set_color (CLUTTER_LABEL (priv->text_actor), priv->text_color);
+      clutter_text_set_color (CLUTTER_TEXT (priv->text_actor),
+          (base_priv->highlighted ? &SELECTED_TEXT_COLOR : priv->text_color));
       if (clutter_actor_get_parent (priv->text_actor) == NULL)
         clutter_container_add_actor (CLUTTER_CONTAINER (marker), priv->text_actor);
     }
@@ -671,8 +768,18 @@ redraw_on_idle (gpointer gobject)
   return FALSE;
 }
 
-static void
-queue_redraw (ChamplainMarker *marker)
+/** champlain_marker_queue_redraw:
+ * @marker: a #ChamplainMarker
+ *
+ * Queue a redraw of the marker as soon as possible. This function should not
+ * be used unless you are subclassing ChamplainMarker and adding new properties
+ * that affect the aspect of the marker.  When they change, call this function
+ * to update the marker.
+ *
+ * Since: 0.4.3
+ */
+void
+champlain_marker_queue_redraw (ChamplainMarker *marker)
 {
   if (!marker->priv->redraw_id)
     marker->priv->redraw_id = g_idle_add (redraw_on_idle, marker);
@@ -683,7 +790,7 @@ notify_highlighted (GObject *gobject,
     GParamSpec *pspec,
     gpointer user_data)
 {
-  queue_redraw (CHAMPLAIN_MARKER (gobject));
+  champlain_marker_queue_redraw (CHAMPLAIN_MARKER (gobject));
 }
 
 static void
@@ -707,6 +814,8 @@ champlain_marker_init (ChamplainMarker *marker)
   priv->ellipsize = PANGO_ELLIPSIZE_NONE;
   priv->draw_background = TRUE;
   priv->redraw_id = 0;
+  priv->shadow = NULL;
+  priv->text_actor = NULL;
 
   g_signal_connect (marker, "notify::highlighted", G_CALLBACK (notify_highlighted), NULL);
 }
@@ -714,7 +823,7 @@ champlain_marker_init (ChamplainMarker *marker)
 /**
  * champlain_marker_new:
  *
- * Returns a new #ChamplainMarker ready to be used as a #ClutterActor.
+ * Returns: a new #ChamplainMarker ready to be used as a #ClutterActor.
  *
  * Since: 0.2
  */
@@ -731,7 +840,7 @@ champlain_marker_new (void)
  * @text_color: a #ClutterColor, the color of the text, can be NULL
  * @marker_color: a #ClutterColor, the color of the marker, can be NULL
  *
- * Returns a new #ChamplainMarker with a drawn marker containing the given text.
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given text.
  *
  * Since: 0.2
  */
@@ -761,7 +870,7 @@ champlain_marker_new_with_text (const gchar *text,
  * champlain_marker_new_with_image:
  * @actor: The actor of the image.
  *
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
  * image.
  *
  * Since: 0.4
@@ -783,7 +892,7 @@ champlain_marker_new_with_image (ClutterActor *actor)
  * @filename: The filename of the image.
  * @error: Return location for an error.
  *
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
  * image.
  *
  * Since: 0.4
@@ -811,7 +920,7 @@ champlain_marker_new_from_file (const gchar *filename,
  * @text: The text
  * @actor: The image
  *
- * Returns a new #ChamplainMarker with a drawn marker containing the given
+ * Returns: a new #ChamplainMarker with a drawn marker containing the given
  * image.
  *
  * Since: 0.4
@@ -851,7 +960,7 @@ champlain_marker_set_text (ChamplainMarker *marker,
     g_free (priv->text);
 
   priv->text = g_strdup (text);
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -872,7 +981,7 @@ champlain_marker_set_image (ChamplainMarker *marker,
   ChamplainMarkerPrivate *priv = marker->priv;
 
   if (priv->image != NULL)
-    g_object_unref (priv->image);
+    clutter_actor_destroy (priv->image);
 
   if (image != NULL)
     {
@@ -883,13 +992,13 @@ champlain_marker_set_image (ChamplainMarker *marker,
     priv->image = image;
 
   g_object_notify (G_OBJECT (marker), "image");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
  * champlain_marker_set_use_markup:
  * @marker: The marker
- * @markup: The value
+ * @use_markup: The value
  *
  * Sets if the marker's text uses markup.
  *
@@ -905,7 +1014,7 @@ champlain_marker_set_use_markup (ChamplainMarker *marker,
 
   priv->use_markup = markup;
   g_object_notify (G_OBJECT (marker), "use-markup");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -927,7 +1036,7 @@ champlain_marker_set_alignment (ChamplainMarker *marker,
 
   priv->alignment = alignment;
   g_object_notify (G_OBJECT (marker), "alignment");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -956,7 +1065,7 @@ champlain_marker_set_color (ChamplainMarker *marker,
 
   priv->color = clutter_color_copy (color);
   g_object_notify (G_OBJECT (marker), "color");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -985,7 +1094,7 @@ champlain_marker_set_text_color (ChamplainMarker *marker,
 
   priv->text_color = clutter_color_copy (color);
   g_object_notify (G_OBJECT (marker), "text-color");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -1014,7 +1123,7 @@ champlain_marker_set_font_name (ChamplainMarker *marker,
 
   priv->font_name = g_strdup (font_name);
   g_object_notify (G_OBJECT (marker), "font-name");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -1036,13 +1145,13 @@ champlain_marker_set_wrap (ChamplainMarker *marker,
 
   priv->wrap = wrap;
   g_object_notify (G_OBJECT (marker), "wrap");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
  * champlain_marker_set_wrap_mode:
  * @marker: The marker
- * @wrap: The marker's wrap.
+ * @wrap_mode: The marker's wrap.
  *
  * Set the marker's text color.
  *
@@ -1058,13 +1167,13 @@ champlain_marker_set_wrap_mode (ChamplainMarker *marker,
 
   priv->wrap_mode = wrap_mode;
   g_object_notify (G_OBJECT (marker), "wrap");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
  * champlain_marker_set_attributes:
  * @marker: The marker
- * @attributes: The marker's text attributes.
+ * @list: The marker's text attributes.
  *
  * Set the marker's text attribute.
  *
@@ -1087,13 +1196,13 @@ champlain_marker_set_attributes (ChamplainMarker *marker,
   priv->attributes = attributes;
 
   g_object_notify (G_OBJECT (marker), "attributes");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
  * champlain_marker_set_ellipsize:
  * @marker: The marker
- * @ellipsize: The marker's ellipsize mode.
+ * @mode: The marker's ellipsize mode.
  *
  * Set the marker's text ellipsize mode.
  *
@@ -1109,7 +1218,7 @@ champlain_marker_set_ellipsize (ChamplainMarker *marker,
 
   priv->ellipsize = ellipsize;
   g_object_notify (G_OBJECT (marker), "ellipsize");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 /**
  * champlain_marker_set_single_line_mode:
@@ -1131,7 +1240,7 @@ champlain_marker_set_single_line_mode (ChamplainMarker *marker,
   priv->single_line_mode = mode;
 
   g_object_notify (G_OBJECT (marker), "single-line-mode");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
@@ -1153,14 +1262,14 @@ champlain_marker_set_draw_background (ChamplainMarker *marker,
 
   priv->draw_background = background;
   g_object_notify (G_OBJECT (marker), "draw-background");
-  queue_redraw (marker);
+  champlain_marker_queue_redraw (marker);
 }
 
 /**
  * champlain_marker_get_image:
  * @marker: The marker
  *
- * Returns the marker's image.
+ * Returns: the marker's image.
  *
  * Since: 0.4
  */
@@ -1178,7 +1287,7 @@ champlain_marker_get_image (ChamplainMarker *marker)
  * champlain_marker_get_use_markup:
  * @marker: The marker
  *
- * Returns if the marker's text contains markup.
+ * Returns: if the marker's text contains markup.
  *
  * Since: 0.4
  */
@@ -1196,7 +1305,7 @@ champlain_marker_get_use_markup (ChamplainMarker *marker)
  * champlain_marker_get_text:
  * @marker: The marker
  *
- * Returns the marker's text.
+ * Returns: the marker's text.
  *
  * Since: 0.4
  */
@@ -1214,7 +1323,7 @@ champlain_marker_get_text (ChamplainMarker *marker)
  * champlain_marker_get_alignment:
  * @marker: The marker
  *
- * Returns the marker's text alignment.
+ * Returns: the marker's text alignment.
  *
  * Since: 0.4
  */
@@ -1232,7 +1341,7 @@ champlain_marker_get_alignment (ChamplainMarker *marker)
  * champlain_marker_get_color:
  * @marker: The marker
  *
- * Returns the marker's color.
+ * Returns: the marker's color.
  *
  * Since: 0.4
  */
@@ -1250,7 +1359,7 @@ champlain_marker_get_color (ChamplainMarker *marker)
  * champlain_marker_get_text_color:
  * @marker: The marker
  *
- * Returns the marker's text color.
+ * Returns: the marker's text color.
  *
  * Since: 0.4
  */
@@ -1268,7 +1377,7 @@ champlain_marker_get_text_color (ChamplainMarker *marker)
  * champlain_marker_get_font_name:
  * @marker: The marker
  *
- * Returns the marker's font name.
+ * Returns: the marker's font name.
  *
  * Since: 0.4
  */
@@ -1286,7 +1395,7 @@ champlain_marker_get_font_name (ChamplainMarker *marker)
  * champlain_marker_get_wrap:
  * @marker: The marker
  *
- * Returns if the marker's text wraps.
+ * Returns: if the marker's text wraps.
  *
  * Since: 0.4
  */
@@ -1304,7 +1413,7 @@ champlain_marker_get_wrap (ChamplainMarker *marker)
  * champlain_marker_get_wrap_mode:
  * @marker: The marker
  *
- * Returns the marker's text wrap mode.
+ * Returns: the marker's text wrap mode.
  *
  * Since: 0.4
  */
@@ -1322,7 +1431,7 @@ champlain_marker_get_wrap_mode (ChamplainMarker *marker)
  * champlain_marker_get_ellipsize:
  * @marker: The marker
  *
- * Returns the marker's text ellipsize mode.
+ * Returns: the marker's text ellipsize mode.
  *
  * Since: 0.4
  */
@@ -1340,7 +1449,7 @@ champlain_marker_get_ellipsize (ChamplainMarker *marker)
  * champlain_marker_get_single_line_mode:
  * @marker: The marker
  *
- * Returns the marker's text single side mode.
+ * Returns: the marker's text single side mode.
  *
  * Since: 0.4
  */
@@ -1358,7 +1467,7 @@ champlain_marker_get_single_line_mode (ChamplainMarker *marker)
  * champlain_marker_get_draw_background:
  * @marker: The marker
  *
- * Returns if the marker's has a background.
+ * Returns: if the marker's has a background.
  *
  * Since: 0.4
  */
