@@ -105,7 +105,8 @@ void champlain_view_set_map_source (ChamplainView *view,
     ChamplainMapSource *map_source);
 void champlain_view_set_size (ChamplainView *view,
     guint width,
-    guint height);
+    guint height)
+    CHAMPLAIN_OBSOLETE_API;
 void champlain_view_set_decel_rate (ChamplainView *view,
     gdouble rate);
 void champlain_view_set_scroll_mode (ChamplainView *view,
@@ -113,11 +114,17 @@ void champlain_view_set_scroll_mode (ChamplainView *view,
 void champlain_view_set_keep_center_on_resize (ChamplainView *view,
     gboolean value);
 void champlain_view_set_show_license (ChamplainView *view, gboolean value);
+void champlain_view_set_license_text (ChamplainView *view, const gchar *text);
+void champlain_view_set_show_scale (ChamplainView *view, gboolean value);
+void champlain_view_set_scale_unit (ChamplainView *view, ChamplainUnit unit);
+void champlain_view_set_max_scale_width (ChamplainView *view, guint value);
 void champlain_view_set_zoom_on_double_click (ChamplainView *view,
     gboolean value);
 
 void champlain_view_add_layer (ChamplainView *view,
     ChamplainLayer *layer);
+void champlain_view_remove_layer (ChamplainView *view,
+    ChamplainLayer *layer);
 
 gboolean champlain_view_get_coords_from_event (ChamplainView *view,
     ClutterEvent *event,
@@ -138,6 +145,10 @@ gdouble champlain_view_get_decel_rate (ChamplainView *view);
 ChamplainScrollMode champlain_view_get_scroll_mode (ChamplainView *view);
 gboolean champlain_view_get_keep_center_on_resize (ChamplainView *view);
 gboolean champlain_view_get_show_license (ChamplainView *view);
+const gchar * champlain_view_get_license_text (ChamplainView *view);
+gboolean champlain_view_get_show_scale (ChamplainView *view);
+guint champlain_view_get_max_scale_width (ChamplainView *view);
+ChamplainUnit champlain_view_get_scale_unit (ChamplainView *view);
 gboolean champlain_view_get_zoom_on_double_click (ChamplainView *view);
 
 void champlain_view_add_polygon (ChamplainView *view,
@@ -145,7 +156,6 @@ void champlain_view_add_polygon (ChamplainView *view,
 void champlain_view_remove_polygon (ChamplainView *view,
     ChamplainPolygon *polygon);
 
-
 G_END_DECLS
 
 #endif
