@@ -63,6 +63,15 @@ enum {
   PROP_BUFFER,
 };
 
+enum
+{
+  /* normal signals */
+  PANNING_COMPLETED,
+  LAST_SIGNAL
+};
+
+static guint signals[LAST_SIGNAL] = { 0, };
+
 static void
 tidy_finger_scroll_get_property (GObject *object, guint property_id,
                                  GValue *value, GParamSpec *pspec)
@@ -131,7 +140,7 @@ tidy_finger_scroll_finalize (GObject *object)
   TidyFingerScrollPrivate *priv = TIDY_FINGER_SCROLL (object)->priv;
 
   g_array_free (priv->motion_buffer, TRUE);
- 
+
   G_OBJECT_CLASS (tidy_finger_scroll_parent_class)->finalize (object);
 }
 
@@ -177,6 +186,11 @@ tidy_finger_scroll_class_init (TidyFingerScrollClass *klass)
                                                       "events to buffer",
                                                       1, G_MAXUINT, 3,
                                                       G_PARAM_READWRITE));
+
+  signals[PANNING_COMPLETED] =
+      g_signal_new ("panning-completed", G_OBJECT_CLASS_TYPE (object_class),
+          G_SIGNAL_RUN_LAST, 0, NULL, NULL,
+          g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
 }
 
 static gboolean
@@ -294,6 +308,8 @@ deceleration_completed_cb (ClutterTimeline *timeline,
   clamp_adjustments (scroll);
   g_object_unref (timeline);
   scroll->priv->deceleration_timeline = NULL;
+
+  g_signal_emit_by_name (scroll, "panning-completed", NULL);
 }
 
 static void
@@ -420,7 +436,7 @@ button_release_event_cb (ClutterActor *actor,
           else
             time_diff = release_time.tv_usec +
                         (G_USEC_PER_SEC - motion_time.tv_usec);
-          
+
           /* On a macbook that's running Ubuntu 9.04 sometimes 'time_diff' is 0
              and this causes a division by 0 when computing 'frac'. This check
              avoids this error.
@@ -433,7 +449,7 @@ button_release_event_cb (ClutterActor *actor,
               /* See how many units to move in 1/60th of a second */
               priv->dx = (x_origin - x) / frac;
               priv->dy = (y_origin - y) / frac;
-              
+
               /* Get adjustments to do step-increment snapping */
               tidy_scrollable_get_adjustments (TIDY_SCROLLABLE (child),
                                                &hadjust,
@@ -443,9 +459,9 @@ button_release_event_cb (ClutterActor *actor,
                   ABS(priv->dy) > 1)
                 {
                   gdouble value, lower, step_increment, d, a, x, y, n;
-                  
+
                   /* TODO: Convert this all to fixed point? */
-                  
+
                   /* We want n, where x / y    n < z,
                    * x = Distance to move per frame
                    * y = Deceleration rate
@@ -454,7 +470,7 @@ button_release_event_cb (ClutterActor *actor,
                    * Rearrange to n = log (x / z) / log (y)
                    * To simplify, z = 1, so n = log (x) / log (y)
                    *
-                   * As z = 1, this will cause stops to be slightly abrupt - 
+                   * As z = 1, this will cause stops to be slightly abrupt -
                    * add a constant 15 frames to compensate.
                    */
                   x = MAX(ABS(priv->dx), ABS(priv->dy));
@@ -471,7 +487,7 @@ button_release_event_cb (ClutterActor *actor,
                    * Using geometric series,
                    *
                    * d = (1 - 1/y    (n+1))/(1 - 1/y)*x
-                   * 
+                   *
                    * Let a = (1 - 1/y    (n+1))/(1 - 1/y),
                    *
                    * d = a * x
@@ -480,7 +496,7 @@ button_release_event_cb (ClutterActor *actor,
                    *
                    * x = d / a
                    */
-                  
+
                   /* Get adjustments, work out y    n */
                   a = (1.0 - 1.0 / pow (y, n + 1)) / (1.0 - 1.0 / y);
 
@@ -499,31 +515,31 @@ button_release_event_cb (ClutterActor *actor,
                   d = ((rint (((value + d) - lower) / step_increment) *
                         step_increment) + lower) - value;
                   priv->dy = (d / a);
-                  
+
                   priv->deceleration_timeline = clutter_timeline_new ((n / 60) * 1000.0);
                 }
               else
                 {
                   gdouble value, lower, step_increment, d, a, y;
-                  
-                  /* Start a short effects timeline to snap to the nearest step 
+
+                  /* Start a short effects timeline to snap to the nearest step
                    * boundary (see equations above)
                    */
                   y = priv->decel_rate;
                   a = (1.0 - 1.0 / pow (y, 4 + 1)) / (1.0 - 1.0 / y);
-                  
+
                   tidy_adjustment_get_values (hadjust, &value, &lower, NULL,
                                               &step_increment, NULL, NULL);
                   d = ((rint ((value - lower) / step_increment) *
                         step_increment) + lower) - value;
                   priv->dx = (d / a);
-                  
+
                   tidy_adjustment_get_values (vadjust, &value, &lower, NULL,
                                               &step_increment, NULL, NULL);
                   d = ((rint ((value - lower) / step_increment) *
                         step_increment) + lower) - value;
                   priv->dy = (d / a);
-                  
+
                   priv->deceleration_timeline = clutter_timeline_new (250);
                 }
 
@@ -545,6 +561,7 @@ button_release_event_cb (ClutterActor *actor,
   if (!decelerating)
     {
       clamp_adjustments (scroll);
+      g_signal_emit_by_name (scroll, "panning-completed", NULL);
     }
 
   /* Pass through events to children.
@@ -553,7 +570,7 @@ button_release_event_cb (ClutterActor *actor,
   if (moved == FALSE)
     clutter_event_put ((ClutterEvent *)event);
 
-  return TRUE;
+  return moved;
 }
 
 static gboolean
@@ -587,6 +604,9 @@ captured_event_cb (ClutterActor     *actor,
       TidyFingerScrollMotion *motion;
       ClutterButtonEvent *bevent = (ClutterButtonEvent *)event;
 
+      if (bevent->source != actor)
+        return FALSE;
+
       /* Reset motion buffer */
       priv->last_motion = 0;
       motion = &g_array_index (priv->motion_buffer, TidyFingerScrollMotion, 0);
